@@ -127,6 +127,17 @@ vtkViewImage2DCollection::vtkViewImage2DCollection() : ExtraRenderWindow(0)
 vtkViewImage2DCollection::~vtkViewImage2DCollection()
 {
   this->Command->Delete();
+
+  std::vector< vtkActor * >::iterator it = PlanesActors.begin();
+  std::vector< vtkActor * >::iterator tmp;
+  while(it!=PlanesActors.end())
+    {
+    // necessary trick on windows
+    tmp = it;
+    ++it;
+    (*tmp)->Delete();
+    }
+
 }
 
 //----------------------------------------------------------------------------
@@ -218,9 +229,7 @@ void vtkViewImage2DCollection::Initialize()
           static_cast< vtkDataSet * >( this->GetItem(i)->GetSlicePlane() ),
           plane_property, ( i != j ), true);
       //store all slice actors
-      this->SlicePlaneActors.push_back(temp);
-      /// \todo Check if delete makes sense here
-      temp->Delete();
+      this->PlanesActors.push_back(temp);
       }
     }
 }
@@ -344,13 +353,13 @@ void
 vtkViewImage2DCollection::SetSplinePlaneActorsVisibility(bool iVisibility)
 {
   // vtkstd::vector<vtkQuadricLODActor*>::iterator
-  vtkstd::vector< vtkActor * >::iterator SlicePlaneActorsIterator =
-    SlicePlaneActors.begin();
+  std::vector< vtkActor * >::iterator PlanesActorsIterator =
+    PlanesActors.begin();
 
-  while ( SlicePlaneActorsIterator != SlicePlaneActors.end() )
+  while ( PlanesActorsIterator != PlanesActors.end() )
     {
-    ( *SlicePlaneActorsIterator )->SetVisibility(iVisibility);
-    ++SlicePlaneActorsIterator;
+    ( *PlanesActorsIterator )->SetVisibility(iVisibility);
+    ++PlanesActorsIterator;
     }
 }
 
@@ -664,4 +673,12 @@ void vtkViewImage2DCollection::EnableContourPickingMode()
     item->SetPickInteractionStyle();
     item = this->GetNextItem();
     }
-}
\ No newline at end of file
+}
+
+//----------------------------------------------------------------------------
+std::vector< vtkActor * >
+vtkViewImage2DCollection::
+GetPlanesActors()
+{
+  return this->PlanesActors;
+}
