@@ -890,4 +890,10 @@ vtkViewImage3D::ComputeDistancesToSquare(vtkPlanes *planes)
   this->InvokeEvent(vtkViewImage3DCommand::UpdateRenderEvent);
 }
 
-//----------------------------------------------------------------------------
\ No newline at end of file
+//----------------------------------------------------------------------------
+std::vector< vtkActor * >
+vtkViewImage3D::
+GetPlanesActors()
+{
+  return this->BoundsActor;
+}
